Fleet Utilization Series
-------------------------

Aggregated from :ref:`Fleet Utilization Vessels`

.. note::
    available on platforms : Platform.Liquids, Platform.LNG, Platform.LPG, Platform.Dry

.. autoclass:: kpler.sdk.resources.fleet_utilization_series.FleetUtilizationSeries
    :members:

.. autoclass:: kpler.sdk.FleetUtilizationSeriesMetric
    :members:

.. autoclass:: kpler.sdk.FleetUtilizationSeriesPeriod
    :members:

.. autoclass:: kpler.sdk.FleetUtilizationSeriesSplit
    :members:

.. autoclass:: kpler.sdk.FleetUtilizationSeriesUnit
    :members:

.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesDry
    :members:
    :noindex:

.. autoclass:: kpler.sdk.FleetUtilizationSeriesVesselsState
    :members:
